@@ -22,12 +22,6 @@ class Option:
             if not isinstance(default, int):
                 raise ValueError("option '%s' default value must be int" % name)
 
-        # This is a hack needed so that "make doc" will work.
-        if name.lower() == "pfringclusterid":
-            val = "0"
-            if "@" not in val:
-                # Use default value supplied by cmake
-                self.default = int(val)
 
 options = [
     # User options.
@@ -43,6 +37,8 @@ options = [
            "The number of seconds to wait before sending a SIGKILL to a node which was previously issued the 'stop' command but did not terminate gracefully."),
     Option("CommTimeout", 10, "int", Option.USER, False,
            "The number of seconds to wait before assuming Broccoli communication events have timed out."),
+    Option("ControlTopic", "bro/control", "string", Option.USER, False,
+           "The Broker topic name used for sending and receiving control messages to Bro processes."),
     Option("CommandTimeout", 60, "int", Option.USER, False,
            "The number of seconds to wait for a command to return results."),
     Option("BroPort", 47760, "int", Option.USER, False,
@@ -60,7 +56,7 @@ options = [
     Option("CompressExtension", "gz", "string", Option.USER, False,
            "If archived logs will be compressed, the file extension to use on compressed log files. When specifying a file extension, don't include the period character (e.g., specify 'gz' instead of '.gz')."),
 
-    Option("SendMail", "/usr/sbin/sendmail", "string", Option.USER, False,
+    Option("SendMail", "/usr/local/sbin/sendmail", "string", Option.USER, False,
            "Location of the sendmail binary.  Make this string blank to prevent email from being sent. The default value is configuration-dependent and determined automatically by CMake at configure-time. This overrides the Bro script variable Notice::sendmail."),
     Option("MailSubjectPrefix", "[Bro]", "string", Option.USER, False,
            "General Subject prefix for mails. This overrides the Bro script variable Notice::mail_subject_prefix."),
@@ -111,14 +107,6 @@ options = [
     Option("Prefixes", "local", "string", Option.USER, False,
            "Additional script prefixes for Bro, separated by colons. Use this instead of @prefix."),
 
-    Option("SitePolicyManager", "local-manager.bro", "string", Option.USER, False,
-           "Space-separated list of local policy files for manager.  This option is deprecated."),
-    Option("SitePolicyLogger", "local-logger.bro", "string", Option.USER, False,
-           "Space-separated list of local policy files for logger.  This option is deprecated."),
-    Option("SitePolicyWorker", "local-worker.bro", "string", Option.USER, False,
-           "Space-separated list of local policy files for workers.  This option is deprecated."),
-    Option("SitePolicyStandalone", "local.bro", "string", Option.USER, False,
-           "Space-separated list of local policy files that will be automatically loaded for all Bro instances.  Scripts listed here do not need to be explicitly loaded from any other policy scripts.  This option is deprecated (please use SitePolicyScripts instead)."),
     Option("SitePolicyScripts", "local.bro", "string", Option.USER, False,
            "Space-separated list of local policy files that will be automatically loaded for all Bro instances.  Scripts listed here do not need to be explicitly loaded from any other policy scripts."),
 
@@ -130,14 +118,14 @@ options = [
     Option("CronCmd", "", "string", Option.USER, False,
            "A custom command to run everytime the cron command has finished."),
 
-    Option("PFRINGClusterID", 0, "int", Option.USER, False,
-           "If PF_RING flow-based load balancing is desired, this is where the PF_RING cluster id is defined. The default value is configuration-dependent and determined automatically by CMake at configure-time based upon whether PF_RING's enhanced libpcap is available.  Bro must be linked with PF_RING's libpcap wrapper for this option to work."),
+    Option("PFRINGClusterID", 21, "int", Option.USER, False,
+           "If PF_RING flow-based load balancing is desired, this is where the PF_RING cluster id is defined.  In order to use PF_RING, the value of this option must be non-zero."),
     Option("PFRINGClusterType", "4-tuple", "string", Option.USER, False,
            "If PF_RING flow-based load balancing is desired, this is where the PF_RING cluster type is defined.  Allowed values are: 2-tuple, 4-tuple, 5-tuple, tcp-5-tuple, 6-tuple, or round-robin.  Bro must be linked with PF_RING's libpcap wrapper and PFRINGClusterID must be non-zero for this option to work."),
     Option("PFRINGFirstAppInstance", 0, "int", Option.USER, False,
            "The first application instance for a PF_RING dnacluster interface to use.  Broctl will start at this application instance number and increment for each new process running on that DNA cluster.  Bro must be linked with PF_RING's libpcap wrapper, PFRINGClusterID must be non-zero, and you must be using PF_RING+DNA and libzero for this option to work."),
 
-    Option("PcapSnaplen", 8192, "int", Option.AUTOMATIC, False,
+    Option("PcapSnaplen", 9216, "int", Option.AUTOMATIC, False,
            "Number of bytes per packet to capture from live interfaces via libpcap."),
     Option("PcapBufsize", 128, "int", Option.AUTOMATIC, False,
            "Number of Mbytes to provide as buffer space when capturing from live interfaces via libpcap."),
@@ -147,11 +135,6 @@ options = [
     Option("TimeMachinePort", "47757/tcp", "string", Option.USER, False,
            "If the manager should connect to a Time Machine, the port it is running on (in Bro syntax, e.g., 47757/tcp)."),
 
-    Option("IPv6Comm", 1, "bool", Option.USER, False,
-           "Enable IPv6 communication between cluster nodes (and also between them and BroControl). This overrides the Bro script variable Communication::listen_ipv6."),
-    Option("ZoneID", "", "string", Option.USER, False,
-           "If the host running BroControl is managing a cluster comprised of nodes with non-global IPv6 addresses, this option indicates what :rfc:`4007` zone_id to append to node addresses when communicating with them."),
-
     # Automatically set.
     Option("BroBase", "", "string", Option.AUTOMATIC, True,
            "Base path of broctl installation on all nodes."),
@@ -218,6 +201,8 @@ options = [
            "Log file for debugging information."),
     Option("StatsLog", "${SpoolDir}/stats.log", "string", Option.AUTOMATIC, False,
            "Log file for statistics."),
+    Option("DefaultStoreDir", "${SpoolDir}/stores", "string", Option.AUTOMATIC, False,
+           "Default directory where Broker data stores will be written if user has not provided further customizations on a per-store basis."),
 
     Option("SitePolicyPath", "${PolicyDir}/site", "string", Option.USER, False,
            "Directories to search for local (i.e., site-specific) policy files, separated by colons. For each such directory, all files and subdirectories are copied to PolicyDirSiteInstall during broctl 'install' or 'deploy' (however, if the same file or subdirectory is found in more than one such directory, then only the first one encountered will be used)."),
